@@ -62,7 +62,18 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
     "VGG16" : '/kaggle/input/tf-keras-pretrained-weights/No Top/vgg16_weights_tf_dim_ordering_tf_kernels_notop.h5',
     "VGG19" : '/kaggle/input/tf-keras-pretrained-weights/No Top/vgg19_weights_tf_dim_ordering_tf_kernels_notop.h5',
     "Xception" : '/kaggle/input/tf-keras-pretrained-weights/No Top/xception_weights_tf_dim_ordering_tf_kernels_notop.h5'
-    }
+	}
+	
+	noisy_weights = {
+	"EfficientNetB0" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b0_noisy-student_notop.h5',
+	"EfficientNetB1" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b1_noisy-student_notop.h5',
+	"EfficientNetB2" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b2_noisy-student_notop.h5',
+	"EfficientNetB3" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b3_noisy-student_notop.h5',
+	"EfficientNetB4" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b4_noisy-student_notop.h5',
+	"EfficientNetB5" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b5_noisy-student_notop.h5',
+	"EfficientNetB6" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b6_noisy-student_notop.h5',
+	"EfficientNetB7" : '/kaggle/input/tf-keras-pretrained-weights/No Top/efficientnet-b7_noisy-student_notop.h5'
+	}
     import os
     
     params = {"input_shape" : input_shape, "weights" : weights, "include_top" : False}
@@ -71,8 +82,10 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
     if os.path.isdir('/kaggle/input/tf-keras-pretrained-weights/No Top'):
         params = {"input_shape" : input_shape, "include_top" : False}
         weights_dir_present = True
-    
-    
+    elif os.path.isdir('/content/No Top'):
+		params = {'input_shape' : input_shape, 'include_top' : False}
+		weights_dir_present = True
+		
     
     if classification_model != 'default':
         print("""
@@ -95,32 +108,51 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
     #tf.keras.backend.clear_session() # error pops
     if model_name == "VGG16":
         if weights_dir_present:
-            pretrained_model = VGG16(weights = weights_dict['VGG16'], **params)
+            try:
+				pretrained_model = VGG16(weights = weights_dict['VGG16'], **params)
+			except:
+				pretrained_model = VGG16(weights = os.path.join('/content', '/'.join(weights_dict['VGG16'].split('/')[4:])), **params)
         else:
             pretrained_model = VGG16(**params)
     elif model_name == "VGG19":
         if weights_dir_present:
-            pretrained_model = VGG19(weights = weights_dict['VGG19'], **params)
+			
+			try:
+				pretrained_model = VGG19(weights = weights_dict['VGG19'], **params)
+			except:
+				pretrained_model = VGG19(weights = os.path.join('/content', '/'.join(weights_dict['VGG19'].split('/')[4:])), **params)
         else:
             pretrained_model = VGG19(**params)
     elif model_name == 'Xception':
         if weights_dir_present:
-            pretrained_model = Xception(weights = weights_dict['Xception'], **params)
+			try:
+				pretrained_model = Xception(weights = weights_dict['Xception'], **params)
+			except:
+				pretrained_model = Xception(weights = os.path.join('/content', '/'.join(weights_dict['Xception'].split('/')[4:])), **params)
         else:
             pretrained_model = Xception(**params)
     elif model_name == "DenseNet121":
         if weights_dir_present:
-            pretrained_model = DenseNet121(weights = weights_dict['DenseNet121'], **params)
+			try:
+				pretrained_model = DenseNet121(weights = weights_dict['DenseNet121'], **params)
+			except:
+				pretrained_model = DenseNet121(weights = os.path.join('/content', '/'.join(weights_dict['DenseNet121'].split('/')[4:])), **params)
         else:
             pretrained_model = DenseNet121(**params)
     elif model_name == "DenseNet169":
         if weights_dir_present:
-            pretrained_model = DenseNet169(weights = weights_dict['DenseNet169'], **params)
+            try:
+				pretrained_model = DenseNet169(weights = weights_dict['DenseNet169'], **params)
+			except:
+				pretrained_model = DenseNet169(weights = os.path.join('/content', '/'.join(weights_dict['DenseNet169'].split('/')[4:])), **params)
         else:
             pretrained_model = DenseNet169(**params)
     elif model_name == "DenseNet201":
         if weights_dir_present:
-            pretrained_model = DenseNet201(weights = weights_dict['DenseNet201'], **params)
+            try:
+				pretrained_model = DenseNet201(weights = weights_dict['DenseNet201'], **params)
+			except:
+				pretrained_model = DenseNet201(weights = os.path.join('/content', '/'.join(weights_dict['DenseNet201'].split('/')[4:])), **params)
         else:
             pretrained_model = DenseNet201(**params)
     elif model_name == 'EfficientNetB7':
@@ -130,7 +162,17 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         #os.system("pip install git+https://github.com/qubvel/segmentation_models")
         import efficientnet.tfkeras as efn   
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB7(weights = weights_dict['EfficientNetB7'], **params)
+		    	
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB7(weights = noisy_weights['EfficientNetB7'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB7(weights = weights_dict['EfficientNetB7'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB7(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB7'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB7(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB7'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB7(**params)
         
@@ -142,7 +184,21 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         
         import efficientnet.tfkeras as efn  
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB6(weights = weights_dict['EfficientNetB6'], **params)
+		
+			
+            try:
+			
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB6(weights = noisy_weights['EfficientNetB6'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB6(weights = weights_dict['EfficientNetB6'], **params)
+					
+			except:
+				
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB6(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB6'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB6(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB6'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB6(**params)
         
@@ -154,7 +210,17 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn   
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB5(weights = weights_dict['EfficientNetB5'], **params)
+            try:
+				
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB5(weights = noisy_weights['EfficientNetB5'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB5(weights = weights_dict['EfficientNetB5'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB5(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB5'].split('/')[4:]), **params)
+				else:
+					pretrained_model = efn.EfficientNetB5(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB5'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB5(**params)
         
@@ -166,7 +232,16 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB4(weights = weights_dict['EfficientNetB4'], **params)
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB4(weights = noisy_weights['EfficientNetB4'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB4(weights = weights_dict['EfficientNetB4'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB4(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB4'].split('/')[4:]), **params)
+				else:
+					pretrained_model = efn.EfficientNetB4(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB4'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB4(**params)
         
@@ -178,7 +253,16 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn  
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB3(weights = weights_dict['EfficientNetB3'], **params)
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB3(weights = noisy_weights['EfficientNetB3'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB3(weights = weights_dict['EfficientNetB3'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB3(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB3'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB3(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB3'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB3(**params)
         
@@ -190,7 +274,16 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn 
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB2(weights = weights_dict['EfficientNetB2'], **params)
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB2(weights = noisy_weights['EfficientNetB2'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB2(weights = weights_dict['EfficientNetB2'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB2(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB2'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB2(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB2'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB2(**params)
         
@@ -202,7 +295,16 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn  
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB1(weights = weights_dict['EfficientNetB1'], **params)
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB1(weights = noisy_weights['EfficientNetB1', **params)
+				else:
+					pretrained_model = efn.EfficientNetB1(weights = weights_dict['EfficientNetB1'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB1(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB1'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB1(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB1'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB1(**params)
         
@@ -214,68 +316,107 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
         import efficientnet.tfkeras as efn 
         
         if weights_dir_present:
-            pretrained_model = efn.EfficientNetB0(weights = weights_dict['EfficientNetB0'], **params)
+            try:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB0(weights = noisy_weights['EfficientNetB0'], **params)
+				else:
+					pretrained_model = efn.EfficientNetB0(weights = weights_dict['EfficientNetB0'], **params)
+			except:
+				if weights == 'noisy-student':
+					pretrained_model = efn.EfficientNetB0(weights = os.path.join('/content', '/'.join(noisy_weights['EfficientNetB0'].split('/')[4:])), **params)
+				else:
+					pretrained_model = efn.EfficientNetB0(weights = os.path.join('/content', '/'.join(weights_dict['EfficientNetB0'].split('/')[4:])), **params)
         else:
             pretrained_model = efn.EfficientNetB0(**params)
         
     elif model_name == "InceptionV3":
         
         if weights_dir_present:
-            pretrained_model = InceptionV3(weights = weights_dict['InceptionV3'], **params)
+            try:
+				pretrained_model = InceptionV3(weights = weights_dict['InceptionV3'], **params)
+			except:
+				pretrained_model = InceptionV3(weights = os.path.join('/content', '/'.join(weights_dict['InceptionV3'].split('/')[4:])), **params)
         else:
             pretrained_model = InceptionV3(**params)
     elif model_name == "ResNet50":
         if weights_dir_present:
-            pretrained_model = ResNet50(weights = weights_dict['ResNet50'], **params)
+            try:
+				pretrained_model = ResNet50(weights = weights_dict['ResNet50'], **params)
+			except:
+				pretrained_model = ResNet50(weights = os.path.join('/content', '/'.join(weights_dict['ResNet50'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet50(**params)
     elif model_name == "ResNet101":
         if weights_dir_present:
-            pretrained_model = ResNet101(weights = weights_dict['ResNet101'], **params)
+            try:
+				pretrained_model = ResNet101(weights = weights_dict['ResNet101'], **params)
+			except:
+				pretrained_model = ResNet101(weights = os.path.join('/content', '/'.join(weights_dict['ResNet101'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet101(**params)
     elif model_name == "ResNet152":
         
         if weights_dir_present:
-            pretrained_model = ResNet152(weights = weights_dict['ResNet152'], **params)
+            try:
+				pretrained_model = ResNet152(weights = weights_dict['ResNet152'], **params)
+			except:
+				pretrained_model = ResNet152(weights = os.path.join('/content', '/'.join(weights_dict['ResNet152'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet152(**params)
     elif model_name == "ResNet50V2":
         
         if weights_dir_present:
-            pretrained_model = ResNet50V2(weights = weights_dict['ResNet50V2'], **params)
+            try:
+				pretrained_model = ResNet50V2(weights = weights_dict['ResNet50V2'], **params)
+			except:
+				pretrained_model = ResNet50V2(weights = os.path.join('/content', '/'.join(weights_dict['ResNet50V2'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet50V2(**params)
     elif model_name == "ResNet101V2":
         
         if weights_dir_present:
-            pretrained_model = ResNet101V2(weights = weights_dict['ResNet101V2'], **params)
+            try:
+				pretrained_model = ResNet101V2(weights = weights_dict['ResNet101V2'], **params)
+			except:
+				pretrained_model = ResNet101V2(weights = os.path.join('/content', '/'.join(weights_dict['ResNet101V2'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet101V2(**params)
             
     elif model_name == "ResNet152V2":
         
         if weights_dir_present:
-            pretrained_model = ResNet152V2(weights = weights_dict['ResNet152V2'], **params)
+            try:
+				pretrained_model = ResNet152V2(weights = weights_dict['ResNet152V2'], **params)
+			except:
+				pretrained_model = ResNet152V2(weights = os.path.join('/content', '/'.join(weights_dict['ResNet152V2'].split('/')[4:])), **params)
         else:
             pretrained_model = ResNet152V2(**params)
     elif model_name == 'MobileNet':
         
         if weights_dir_present:
-            pretrained_model = MobileNet(weights = weights_dict['MobileNet'], **params)
+            try:
+				pretrained_model = MobileNet(weights = weights_dict['MobileNet'], **params)
+			except:
+				pretrained_model = MobileNet(weights = os.path.join('/content', '/'.join(weights_dict['MobileNet'].split('/')[4:])), **params)
         else:
             pretrained_model = MobileNet(**params)    
     elif model_name == 'MobileNetV2':
         
         if weights_dir_present:
-            pretrained_model = MobileNetV2(weights = weights_dict['MobileNetV2'], **params)
+			try:
+				pretrained_model = MobileNetV2(weights = weights_dict['MobileNetV2'], **params)
+			except:
+				pretrained_model = MobileNetV2(weights = os.path.join('/content', '/'.join(weights_dict['MobileNetV2'].split('/')[4:])), **params)
         else:
             pretrained_model = MobileNetV2(**params)
             
     elif model_name == "InceptionResNetV2":
         
         if weights_dir_present:
-            pretrained_model = InceptionResNetV2(weights = weights_dict['InceptionResNetV2'], **params)
+			try:
+				pretrained_model = InceptionResNetV2(weights = weights_dict['InceptionResNetV2'], **params)
+			except:
+				pretrained_model = InceptionResNetV2(weights = os.path.join('/content', '/'.join(weights_dict['InceptionResNetV2'].split('/')[4:])), **params)
         else:
             pretrained_model = InceptionResNetV2(**params)
 
