@@ -46,6 +46,89 @@ def get_addrs_labels(data_dir):
 
 	return addrs, labels
 
+
+def affirmationcsv(func):
+	def inner(*args, **kwargs):
+
+		print("""Please ensure that the data format is of the following structure. -> \n
+
+			csv file format. 
+
+			| Image      | Id    |
+			------------------
+			|Image1.jpg  | classA|
+			|Image2.jpg  | classB|
+			|Image3.jpg  | classA|
+			|Image4.jpg  | classC|
+			|ImageN.jpg  | classN|
+
+			AND
+
+			DATA_DIR of Images follows the following structure -> \n
+
+			/data 
+				|
+				|-> Image1.jpg
+				|-> Image2.jpg
+				|-> Image3.jpg
+				|
+				|-> ImageN.jpg
+
+
+			""")
+		func(*args, **kwargs)
+
+	return inner
+
+@affirmationcsv
+def create_tfrecords_from_csv(data_dir, csv_path, outputfilename, IMAGE_SIZE = (192,192)):
+	
+
+	import pandas as pd 
+	df = pd.read_csv(csv_path)
+
+	df.sort_values(['Image'], axis = 0, inplace = True)
+
+	addrs = glob.glob(DATA_DIR + '/*.jpg')
+	addrs.sort()
+	labels = list(df['Image'])
+
+	c = list(zip(addrs, labels))
+	shuffle(c)
+
+
+	addrs, labels = zip(*c)
+	create_tfrecord_labeled(addrs, labels, outputfilename, IMAGE_SIZE)
+
+
+
+@affirmationcsv
+def create_split_tfrecords_from_csv(data_dir, csv, outfile1name, outfile2name, split_size_ratio , IMAGE_SIZE = (192,192)):
+	
+	import pandas as pd
+	df = pd.read_csv(csv_path)
+
+	df.sort_values(['Image'], axis = 0, inplace = True)
+
+	addrs = glob.glob(DATA_DIR + '/*.jpg')
+	addrs.sort()
+	labels = list(df['Image'])
+
+	c = list(zip(addrs, labels))
+	shuffle(c)
+	addrs, labels = zip(*c)
+
+	file1_addrs = addrs[0 : int(split_size_ratio * len(addrs))]
+	file1_labels = labels[0: int(split_size_ratio * len(labels))]
+
+	file2_addrs = addrs[int(split_size_ratio * len(addrs)) :]
+	file2_labels =  labels[int(split_size_ratio * len(labels)):]
+
+	create_tfrecord_labeled(file1_addrs, file1_labels, outfile1name, IMAGE_SIZE)
+	create_tfrecord_labeled(file2_addrs, file2_labels, outfile2name, IMAGE_SIZE)
+
+
+
 def create_split_tfrecords_data(data_dir, outfile1name, outfile2name, split_size_ratio, IMAGE_SIZE = (192,192)):
 
 	print(f"Split ratio -> {split_size_ratio}")
@@ -63,10 +146,9 @@ def create_split_tfrecords_data(data_dir, outfile1name, outfile2name, split_size
 	print("Data Successfully created!")
 
 
-def create_tfrecord_labeled(addrs, labels, out_filename, IMAGE_SIZE = (192,192)):
-
-
-	print("""
+def affirmationfolder(func):
+	def inner(*args,**kwargs):
+		print("""
 		Ensure that the data directory has the following structure ->
 
 		/data|
@@ -82,6 +164,13 @@ def create_tfrecord_labeled(addrs, labels, out_filename, IMAGE_SIZE = (192,192))
 
 		the input to data_dir must the path to /data folder. & Make sure that the images are in .jpg format
 		""")
+		func(*args, **kwargs)
+	return inner
+
+@affirmationfolder
+def create_tfrecord_labeled(addrs, labels, out_filename, IMAGE_SIZE = (192,192)):
+
+
 
 	print(f"Beginning to write data to {out_filename}\n\n")
 	writer = tf.io.TFRecordWriter(out_filename)
